-- $Header: histogram_tb_structure_arch.vhd,v 1.1 97/04/09 13:06:22 vaa2878 Exp $

library IEEE;
library project_lib;
use STD.textio.all;
use IEEE.std_logic_1164.all;
use project_lib.xyz_types.all;
use project_lib.arithmetic.all;
use project_lib.convert.all;
use project_lib.io.all;
use project_lib.mem.all;
use project_lib.model_pack.all;
use project_lib.strings.all;
use project_lib.timing.all;
use project_lib.xyz_bm.all;
use project_lib.sram_timing.all;

architecture structure of histogram_tb is
   component histogram
      port(
         clk2xIn            : in std_logic;
         clkIn              : in std_logic;
         cpuAddrIn          : in std_logic_vector(23 downto 0);
         cpuDataStrobeLowIn : in std_logic;
         cpuWriteEnLowIn    : in std_logic;
         horizBlankIn       : in std_logic;
         pixelDataIn        : in std_logic_vector(7 downto 0);
         resetLowIn         : in std_logic;
         vertBlankIn        : in std_logic;
         eofIntLowOut       : out std_logic;
         histAddrOut        : out std_logic_vector(7 downto 0);
         histChipSelLowOut  : out std_logic;
         histWriteEnLowOut  : out std_logic;
         statDataOut        : out std_logic_vector(7 downto 0);
         statDataValidOut   : out std_logic;
         vidAddrOut         : out std_logic_vector(7 downto 0);
         vidChipSelLowOut   : out std_logic;
         vidWriteEnLowOut   : out std_logic;
         cpuDataBi          : inout std_logic_vector(15 downto 0);
         histDataBi         : inout std_logic_vector(7 downto 0);
         vidDataBi          : inout std_logic_vector(7 downto 0)
      );
   end component;
   component histdriver
      port(
         eofIntLowOut       : in std_logic;
         histAddrOut        : in std_logic_vector(7 downto 0);
         histChipSelLowOut  : in std_logic;
         histWriteEnLowOut  : in std_logic;
         statDataOut        : in std_logic_vector(7 downto 0);
         statDataValidOut   : in std_logic;
         vidAddrOut         : in std_logic_vector(7 downto 0);
         vidChipSelLowOut   : in std_logic;
         vidWriteEnLowOut   : in std_logic;
         clk2xIn            : out std_logic;
         clkIn              : out std_logic;
         cpuAddrIn          : out std_logic_vector(23 downto 0);
         cpuDataStrobeLowIn : out std_logic;
         cpuWriteEnLowIn    : out std_logic;
         horizBlankIn       : out std_logic;
         pixelDataIn        : out std_logic_vector(7 downto 0);
         resetLowIn         : out std_logic;
         vertBlankIn        : out std_logic;
         cpuDataBi          : inout std_logic_vector(15 downto 0);
         histDataBi         : inout std_logic_vector(7 downto 0);
         vidDataBi          : inout std_logic_vector(7 downto 0)
      );
   end component;

   component sram
      generic (
         version          : string(1 to 20) := "sram-20             ";
         data_file        : string := "sram.dat";
         gen_option       : time_options    := MAXIMUM;
         gen_global       : boolean         := FALSE;
         gen_time_check   : boolean         := TRUE;
         gen_x_check      : boolean         := TRUE;
         gen_annotated    : boolean         := FALSE;
         gen_debug_level  : integer         := 0;
         gen_vlt          : integer         := 5000;
         gen_tmp          : integer         :=  300;
         gen_DF           : integer         :=  100;
         id_number        : natural         :=   0;
         tfs_a_ce1        : time := 0 ns;
         tfh_a_ce1        : time := 0 ns;
         twd_a            : time_vector(7 downto 0) := (0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns);
         trs_io_ce1       : time := 0 ns;
         trh_io_ce1       : time := 0 ns;
         twd_io           : time_vector(7 downto 0) := (0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns);
         tpr_ce1_io       : delay := (0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns);
         tld_io           : time_vector(7 downto 0) := (0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns);
         tcy_min_ce1      : time := 0 ns;
         tcy_max_ce1      : time := 0 ns;
         tpwh_min_ce1     : time := 0 ns;
         tpwh_max_ce1     : time := 0 ns;
         tpwl_min_ce1     : time := 0 ns;
         tpwl_max_ce1     : time := 0 ns;
         twd_ce1          : time := 0 ns;
         tcy_min_oe       : time := 0 ns;
         tcy_max_oe       : time := 0 ns;
         tpwh_min_oe      : time := 0 ns;
         tpwh_max_oe      : time := 0 ns;
         tpwl_min_oe      : time := 0 ns;
         tpwl_max_oe      : time := 0 ns;
         twd_oe           : time := 0 ns;
         tcy_min_we       : time := 0 ns;
         tcy_max_we       : time := 0 ns;
         tpwh_min_we      : time := 0 ns;
         tpwh_max_we      : time := 0 ns;
         tpwl_min_we      : time := 0 ns;
         tpwl_max_we      : time := 0 ns;
         twd_we           : time := 0 ns;
         tfs_a_we         : time := 0 ns;
         tfh_a_we         : time := 0 ns;
         tfs_io_ce1       : time := 0 ns;
         tfh_io_ce1       : time := 0 ns;
         tpf_ce1_io       : delay := (0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns);
         thfx_ce1_io      : time := 0 ns;
         trfs_we_ce1      : time := 0 ns;
         trfh_we_ce1      : time := 0 ns;
         trfs_ce1_we      : time := 0 ns;
         trfh_ce1_we      : time := 0 ns;
         trs_io_a         : time := 0 ns;
         trh_io_a         : time := 0 ns;
         tpr_a_io         : delay := (0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns);
         thrx_a_io        : time := 0 ns;
         tfs_io_we        : time := 0 ns;
         tfh_io_we        : time := 0 ns;
         tpf_we_io        : delay := (0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns);
         trs_a_ce1        : time := 0 ns;
         trh_a_ce1        : time := 0 ns;
         trs_a_we         : time := 0 ns;
         trh_a_we         : time := 0 ns;
         trs_io_we        : time := 0 ns;
         trh_io_we        : time := 0 ns;
         tpr_we_io        : delay := (0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns);
         tfs_io_oe        : time := 0 ns;
         tfh_io_oe        : time := 0 ns;
         tpf_oe_io        : delay := (0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns);
         thfx_oe_io       : time := 0 ns;
         trs_io_oe        : time := 0 ns;
         trh_io_oe        : time := 0 ns;
         tpr_oe_io        : delay := (0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns,0 ns)
      );
      port ( 
         a   : in    std_logic_vector(7 downto 0);
         io  : inout std_logic_vector(7 downto 0);
         ce1 : in    std_logic;
         oe  : in    std_logic;
         we  : in    std_logic
      );
      end component;

   for all:histogram use entity work.histogram(structure);
   for all:histdriver use entity project_lib.histdriver(behav);
   for all:sram use entity project_lib.sram(structure);
   
   signal clk2xSig            : std_logic;
   signal clkSig              : std_logic;
   signal cpuAddrSig          : std_logic_vector(23 downto 0);
   signal cpuDataStrobeLowSig : std_logic;
   signal cpuWriteEnLowSig    : std_logic;
   signal horizBlankSig       : std_logic;
   signal pixelDataSig        : std_logic_vector(7 downto 0);
   signal resetLowSig         : std_logic;
   signal vertBlankSig        : std_logic;
   signal eofIntLowSig        : std_logic;
   signal histAddrSig         : std_logic_vector(7 downto 0);
   signal histChipSelLowSig   : std_logic;
   signal histWriteEnLowSig   : std_logic;
   signal statDataSig         : std_logic_vector(7 downto 0);
   signal statDataValidSig    : std_logic;
   signal vidAddrSig          : std_logic_vector(7 downto 0);
   signal vidChipSelLowSig    : std_logic;
   signal vidWriteEnLowSig    : std_logic;
   signal cpuDataSig          : std_logic_vector(15 downto 0);
   signal histDataSig         : std_logic_vector(7 downto 0);
   signal vidDataSig          : std_logic_vector(7 downto 0);
      
   signal GND                 : std_logic := '0';
begin
   hist_inst:histogram
      port map(
         clk2xIn            => clk2xSig,
         clkIn              => clkSig,
         cpuAddrIn          => cpuAddrSig,
         cpuDataStrobeLowIn => cpuDataStrobeLowSig,
         cpuWriteEnLowIn    => cpuWriteEnLowSig,
         horizBlankIn       => horizBlankSig,
         pixelDataIn        => pixelDataSig,
         resetLowIn         => resetLowSig,
         vertBlankIn        => vertBlankSig,
         eofIntLowOut       => eofIntLowSig,
         histAddrOut        => histAddrSig,
         histChipSelLowOut  => histChipSelLowSig,
         histWriteEnLowOut  => histWriteEnLowSig,
         statDataOut        => statDataSig,
         statDataValidOut   => statDataValidSig,
         vidAddrOut         => vidAddrSig,
         vidChipSelLowOut   => vidChipSelLowSig,
         vidWriteEnLowOut   => vidWriteEnLowSig,
         cpuDataBi          => cpuDataSig,
         histDataBi         => histDataSig,
         vidDataBi          => vidDataSig
      );

   histdriver_inst:histdriver
      port map(
         eofIntLowOut       => eofIntLowSig,
         histAddrOut        => histAddrSig,
         histChipSelLowOut  => histChipSelLowSig,
         histWriteEnLowOut  => histWriteEnLowSig,
         statDataOut        => statDataSig,
         statDataValidOut   => statDataValidSig,
         vidAddrOut         => vidAddrSig,
         vidChipSelLowOut   => vidChipSelLowSig,
         vidWriteEnLowOut   => vidWriteEnLowSig,
         clk2xIn            => clk2xSig,
         clkIn              => clkSig,
         cpuAddrIn          => cpuAddrSig,
         cpuDataStrobeLowIn => cpuDataStrobeLowSig,
         cpuWriteEnLowIn    => cpuWriteEnLowSig,
         horizBlankIn       => horizBlankSig,
         pixelDataIn        => pixelDataSig,
         resetLowIn         => resetLowSig,
         vertBlankIn        => vertBlankSig,
         cpuDataBi          => cpuDataSig,
         histDataBi         => histDataSig,
         vidDataBi          => vidDataSig
      );

   vidram_inst:sram
      port map ( 
         a   => vidAddrSig,
         io  => vidDataSig,
         ce1 => vidChipSelLowSig,
         oe  => GND,
         we  => vidWriteEnLowSig
      );

   histram_inst:sram
      port map ( 
         a   => histAddrSig,
         io  => histDataSig,
         ce1 => histChipSelLowSig,
         oe  => GND,
         we  => histWriteEnLowSig
      );

end structure;
